@@ -102,6 +102,8 @@ class FileSystemStorage(Storage):
     # For example, when a dataset is empty.
     default_storage_variant: StorageVariant = "jsonl"
 
+    warn_when_scanning_jsonl_series: bool = False
+
     def __enter__(self) -> "FileSystemStorage":
         """Initialize file objects cache that enables keeping many series.jsonl files open."""
         self._series_jsonl_file_objects: Dict[DatasetCode, BinaryIO] = {}
@@ -680,7 +682,6 @@ class FileSystemStorage(Storage):
         include_observations: bool = True,
         on_error: Literal["log", "raise"] = "raise",
         series_codes: Optional[Iterable[SeriesCode]] = None,
-        warn_when_scanning: bool = True,
     ) -> Iterator[tuple[Series, SeriesJsonLinesOffset]]:
         ...
 
@@ -693,7 +694,6 @@ class FileSystemStorage(Storage):
         include_observations: bool = True,
         on_error: Literal["yield"],
         series_codes: Optional[Iterable[SeriesCode]] = None,
-        warn_when_scanning: bool = True,
     ) -> Iterator[Union[tuple[Series, SeriesJsonLinesOffset], DBnomicsDataModelError]]:
         ...
 
@@ -705,7 +705,6 @@ class FileSystemStorage(Storage):
         include_observations: bool = True,
         on_error: OnError = "raise",
         series_codes: Optional[Iterable[SeriesCode]] = None,
-        warn_when_scanning: bool = True,
     ) -> Union[
         Iterator[tuple[Series, SeriesJsonLinesOffset]],
         Iterator[Union[tuple[Series, SeriesJsonLinesOffset], DBnomicsDataModelError]],
@@ -716,11 +715,7 @@ class FileSystemStorage(Storage):
 
         for series_index, data_or_exc in enumerate(
             self._iter_series_jsonl_data(
-                dataset_code,
-                include_observations=include_observations,
-                on_error=on_error,
-                series_codes=series_codes,
-                warn_when_scanning=warn_when_scanning,
+                dataset_code, include_observations=include_observations, on_error=on_error, series_codes=series_codes
             )
         ):
             if isinstance(data_or_exc, DBnomicsDataModelError):
@@ -754,7 +749,6 @@ class FileSystemStorage(Storage):
         include_observations: bool = True,
         on_error: Literal["log", "raise"] = "raise",
         series_codes: Optional[Iterable[SeriesCode]] = None,
-        warn_when_scanning: bool = True,
     ) -> Iterator[tuple[dict, SeriesJsonLinesOffset]]:
         ...
 
@@ -766,7 +760,6 @@ class FileSystemStorage(Storage):
         include_observations: bool = True,
         on_error: Literal["yield"],
         series_codes: Optional[Iterable[SeriesCode]] = None,
-        warn_when_scanning: bool = True,
     ) -> Iterator[Union[Iterator[tuple[dict, SeriesJsonLinesOffset]], DBnomicsDataModelError]]:
         ...
 
@@ -777,7 +770,6 @@ class FileSystemStorage(Storage):
         include_observations: bool = True,
         on_error: OnError = "raise",
         series_codes: Optional[Iterable[SeriesCode]] = None,
-        warn_when_scanning: bool = True,
     ) -> Union[
         Iterator[tuple[dict, SeriesJsonLinesOffset]],
         Iterator[Union[Iterator[tuple[dict, SeriesJsonLinesOffset]], DBnomicsDataModelError]],
@@ -802,7 +794,7 @@ class FileSystemStorage(Storage):
             )
 
         if remaining_series_codes is None or remaining_series_codes:
-            if warn_when_scanning:
+            if self.warn_when_scanning_jsonl_series:
                 logger.warning(
                     "%s of the dataset %r are about to be loaded by scanning its JSON Lines file, "
                     "this is a performance bottleneck",
